@@ -23,7 +23,7 @@ def prepare_data(play_dir, pdb_dir):
     ref = mols[:][0]
     atoms = [i for i in range(ref.GetNumAtoms())]
     mols_pair = list(zip(mols, mols_h))
-    random.shuffle(mols)
+    random.shuffle(mols_pair)
 
     # calc rmsd
     best_mol = None
